# pyAUDP (Python Asynchronous UDP)

**pyAUDP** is a Python library for implementing asynchronous User Datagram Protocol (UDP)
functionalities over Python Socket object.

## Installation

To install pyAUDP, run the following command:

```bash
python3 -m pip install pyAUDP

